# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import List
from typing_extensions import Literal, NotRequired, TypedDict


class RequestedSessionConfirmParams(RequestOptions):
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    payment_method: NotRequired[str]
    """
    The PaymentMethod to use with the requested session.
    """
    payment_method_data: NotRequired[
        "RequestedSessionConfirmParamsPaymentMethodData"
    ]
    """
    The payment method data for this requested session.
    """
    risk_details: NotRequired["RequestedSessionConfirmParamsRiskDetails"]
    """
    Risk details/signals associated with the requested session
    """


class RequestedSessionConfirmParamsPaymentMethodData(TypedDict):
    billing_details: NotRequired[
        "RequestedSessionConfirmParamsPaymentMethodDataBillingDetails"
    ]
    """
    The billing details for the payment method data.
    """
    card: NotRequired["RequestedSessionConfirmParamsPaymentMethodDataCard"]
    """
    The card for the payment method data.
    """
    type: NotRequired[Literal["card"]]
    """
    The type of the payment method data.
    """


class RequestedSessionConfirmParamsPaymentMethodDataBillingDetails(TypedDict):
    address: NotRequired[
        "RequestedSessionConfirmParamsPaymentMethodDataBillingDetailsAddress"
    ]
    """
    The address for the billing details.
    """
    email: NotRequired[str]
    """
    The email for the billing details.
    """
    name: NotRequired[str]
    """
    The name for the billing details.
    """
    phone: NotRequired[str]
    """
    The phone for the billing details.
    """


class RequestedSessionConfirmParamsPaymentMethodDataBillingDetailsAddress(
    TypedDict,
):
    city: str
    """
    City, district, suburb, town, or village.
    """
    country: str
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: str
    """
    Address line 1, such as the street, PO Box, or company name.
    """
    line2: NotRequired[str]
    """
    Address line 2, such as the apartment, suite, unit, or building.
    """
    postal_code: str
    """
    ZIP or postal code.
    """
    state: str
    """
    State, county, province, or region ([ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2)).
    """


class RequestedSessionConfirmParamsPaymentMethodDataCard(TypedDict):
    cvc: NotRequired[str]
    """
    The CVC of the card.
    """
    exp_month: int
    """
    The expiration month of the card.
    """
    exp_year: int
    """
    The expiration year of the card.
    """
    number: str
    """
    The number of the card.
    """


class RequestedSessionConfirmParamsRiskDetails(TypedDict):
    client_device_metadata_details: NotRequired[
        "RequestedSessionConfirmParamsRiskDetailsClientDeviceMetadataDetails"
    ]
    """
    The client device metadata details for this requested session.
    """


class RequestedSessionConfirmParamsRiskDetailsClientDeviceMetadataDetails(
    TypedDict,
):
    radar_session: NotRequired[str]
    """
    The radar session.
    """
    referrer: NotRequired[str]
    """
    The referrer of the client device.
    """
    remote_ip: NotRequired[str]
    """
    The remote IP address of the client device.
    """
    time_on_page_ms: NotRequired[int]
    """
    The time on page in milliseconds.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the client device.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.test_helpers.capital._financing_offer_service import (
        FinancingOfferService as FinancingOfferService,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "FinancingOfferService": (
        "stripe.test_helpers.capital._financing_offer_service",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._createable_api_resource import CreateableAPIResource
from stripe._expandable_field import ExpandableField
from stripe._list_object import ListObject
from stripe._listable_api_resource import ListableAPIResource
from stripe._stripe_object import StripeObject
from stripe._test_helpers import APIResourceTestHelpers
from stripe._util import class_method_variant, sanitize_id
from typing import ClassVar, Dict, Optional, cast, overload
from typing_extensions import Literal, Type, Unpack, TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._mandate import Mandate
    from stripe.params.treasury._inbound_transfer_cancel_params import (
        InboundTransferCancelParams,
    )
    from stripe.params.treasury._inbound_transfer_create_params import (
        InboundTransferCreateParams,
    )
    from stripe.params.treasury._inbound_transfer_fail_params import (
        InboundTransferFailParams,
    )
    from stripe.params.treasury._inbound_transfer_list_params import (
        InboundTransferListParams,
    )
    from stripe.params.treasury._inbound_transfer_retrieve_params import (
        InboundTransferRetrieveParams,
    )
    from stripe.params.treasury._inbound_transfer_return_inbound_transfer_params import (
        InboundTransferReturnInboundTransferParams,
    )
    from stripe.params.treasury._inbound_transfer_succeed_params import (
        InboundTransferSucceedParams,
    )
    from stripe.treasury._transaction import Transaction


class InboundTransfer(
    CreateableAPIResource["InboundTransfer"],
    ListableAPIResource["InboundTransfer"],
):
    """
    Use [InboundTransfers](https://docs.stripe.com/docs/treasury/moving-money/financial-accounts/into/inbound-transfers) to add funds to your [FinancialAccount](https://api.stripe.com#financial_accounts) via a PaymentMethod that is owned by you. The funds will be transferred via an ACH debit.

    Related guide: [Moving money with Treasury using InboundTransfer objects](https://docs.stripe.com/docs/treasury/moving-money/financial-accounts/into/inbound-transfers)
    """

    OBJECT_NAME: ClassVar[Literal["treasury.inbound_transfer"]] = (
        "treasury.inbound_transfer"
    )

    class FailureDetails(StripeObject):
        code: Literal[
            "account_closed",
            "account_frozen",
            "bank_account_restricted",
            "bank_ownership_changed",
            "debit_not_authorized",
            "incorrect_account_holder_address",
            "incorrect_account_holder_name",
            "incorrect_account_holder_tax_id",
            "insufficient_funds",
            "invalid_account_number",
            "invalid_currency",
            "no_account",
            "other",
        ]
        """
        Reason for the failure.
        """

    class LinkedFlows(StripeObject):
        received_debit: Optional[str]
        """
        If funds for this flow were returned after the flow went to the `succeeded` state, this field contains a reference to the ReceivedDebit return.
        """

    class OriginPaymentMethodDetails(StripeObject):
        class BillingDetails(StripeObject):
            class Address(StripeObject):
                city: Optional[str]
                """
                City, district, suburb, town, or village.
                """
                country: Optional[str]
                """
                Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
                """
                line1: Optional[str]
                """
                Address line 1, such as the street, PO Box, or company name.
                """
                line2: Optional[str]
                """
                Address line 2, such as the apartment, suite, unit, or building.
                """
                postal_code: Optional[str]
                """
                ZIP or postal code.
                """
                state: Optional[str]
                """
                State, county, province, or region ([ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2)).
                """

            address: Address
            email: Optional[str]
            """
            Email address.
            """
            name: Optional[str]
            """
            Full name.
            """
            _inner_class_types = {"address": Address}

        class UsBankAccount(StripeObject):
            account_holder_type: Optional[Literal["company", "individual"]]
            """
            Account holder type: individual or company.
            """
            account_type: Optional[Literal["checking", "savings"]]
            """
            Account type: checkings or savings. Defaults to checking if omitted.
            """
            bank_name: Optional[str]
            """
            Name of the bank associated with the bank account.
            """
            fingerprint: Optional[str]
            """
            Uniquely identifies this particular bank account. You can use this attribute to check whether two bank accounts are the same.
            """
            last4: Optional[str]
            """
            Last four digits of the bank account number.
            """
            mandate: Optional[ExpandableField["Mandate"]]
            """
            ID of the mandate used to make this payment.
            """
            network: Literal["ach"]
            """
            The network rails used. See the [docs](https://docs.stripe.com/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.
            """
            routing_number: Optional[str]
            """
            Routing number of the bank account.
            """

        billing_details: BillingDetails
        type: Literal["us_bank_account"]
        """
        The type of the payment method used in the InboundTransfer.
        """
        us_bank_account: Optional[UsBankAccount]
        _inner_class_types = {
            "billing_details": BillingDetails,
            "us_bank_account": UsBankAccount,
        }

    class StatusTransitions(StripeObject):
        canceled_at: Optional[int]
        """
        Timestamp describing when an InboundTransfer changed status to `canceled`.
        """
        failed_at: Optional[int]
        """
        Timestamp describing when an InboundTransfer changed status to `failed`.
        """
        succeeded_at: Optional[int]
        """
        Timestamp describing when an InboundTransfer changed status to `succeeded`.
        """

    amount: int
    """
    Amount (in cents) transferred.
    """
    cancelable: bool
    """
    Returns `true` if the InboundTransfer is able to be canceled.
    """
    created: int
    """
    Time at which the object was created. Measured in seconds since the Unix epoch.
    """
    currency: str
    """
    Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """
    description: Optional[str]
    """
    An arbitrary string attached to the object. Often useful for displaying to users.
    """
    failure_details: Optional[FailureDetails]
    """
    Details about this InboundTransfer's failure. Only set when status is `failed`.
    """
    financial_account: str
    """
    The FinancialAccount that received the funds.
    """
    hosted_regulatory_receipt_url: Optional[str]
    """
    A [hosted transaction receipt](https://docs.stripe.com/treasury/moving-money/regulatory-receipts) URL that is provided when money movement is considered regulated under Stripe's money transmission licenses.
    """
    id: str
    """
    Unique identifier for the object.
    """
    linked_flows: LinkedFlows
    livemode: bool
    """
    Has the value `true` if the object exists in live mode or the value `false` if the object exists in test mode.
    """
    metadata: Dict[str, str]
    """
    Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
    """
    object: Literal["treasury.inbound_transfer"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """
    origin_payment_method: Optional[str]
    """
    The origin payment method to be debited for an InboundTransfer.
    """
    origin_payment_method_details: Optional[OriginPaymentMethodDetails]
    """
    Details about the PaymentMethod for an InboundTransfer.
    """
    returned: Optional[bool]
    """
    Returns `true` if the funds for an InboundTransfer were returned after the InboundTransfer went to the `succeeded` state.
    """
    statement_descriptor: str
    """
    Statement descriptor shown when funds are debited from the source. Not all payment networks support `statement_descriptor`.
    """
    status: Literal["canceled", "failed", "processing", "succeeded"]
    """
    Status of the InboundTransfer: `processing`, `succeeded`, `failed`, and `canceled`. An InboundTransfer is `processing` if it is created and pending. The status changes to `succeeded` once the funds have been "confirmed" and a `transaction` is created and posted. The status changes to `failed` if the transfer fails.
    """
    status_transitions: StatusTransitions
    transaction: Optional[ExpandableField["Transaction"]]
    """
    The Transaction associated with this object.
    """

    @classmethod
    def _cls_cancel(
        cls,
        inbound_transfer: str,
        **params: Unpack["InboundTransferCancelParams"],
    ) -> "InboundTransfer":
        """
        Cancels an InboundTransfer.
        """
        return cast(
            "InboundTransfer",
            cls._static_request(
                "post",
                "/v1/treasury/inbound_transfers/{inbound_transfer}/cancel".format(
                    inbound_transfer=sanitize_id(inbound_transfer)
                ),
                params=params,
            ),
        )

    @overload
    @staticmethod
    def cancel(
        inbound_transfer: str, **params: Unpack["InboundTransferCancelParams"]
    ) -> "InboundTransfer":
        """
        Cancels an InboundTransfer.
        """
        ...

    @overload
    def cancel(
        self, **params: Unpack["InboundTransferCancelParams"]
    ) -> "InboundTransfer":
        """
        Cancels an InboundTransfer.
        """
        ...

    @class_method_variant("_cls_cancel")
    def cancel(  # pyright: ignore[reportGeneralTypeIssues]
        self, **params: Unpack["InboundTransferCancelParams"]
    ) -> "InboundTransfer":
        """
        Cancels an InboundTransfer.
        """
        return cast(
            "InboundTransfer",
            self._request(
                "post",
                "/v1/treasury/inbound_transfers/{inbound_transfer}/cancel".format(
                    inbound_transfer=sanitize_id(self.get("id"))
                ),
                params=params,
            ),
        )

    @classmethod
    async def _cls_cancel_async(
        cls,
        inbound_transfer: str,
        **params: Unpack["InboundTransferCancelParams"],
    ) -> "InboundTransfer":
        """
        Cancels an InboundTransfer.
        """
        return cast(
            "InboundTransfer",
            await cls._static_request_async(
                "post",
                "/v1/treasury/inbound_transfers/{inbound_transfer}/cancel".format(
                    inbound_transfer=sanitize_id(inbound_transfer)
                ),
                params=params,
            ),
        )

    @overload
    @staticmethod
    async def cancel_async(
        inbound_transfer: str, **params: Unpack["InboundTransferCancelParams"]
    ) -> "InboundTransfer":
        """
        Cancels an InboundTransfer.
        """
        ...

    @overload
    async def cancel_async(
        self, **params: Unpack["InboundTransferCancelParams"]
    ) -> "InboundTransfer":
        """
        Cancels an InboundTransfer.
        """
        ...

    @class_method_variant("_cls_cancel_async")
    async def cancel_async(  # pyright: ignore[reportGeneralTypeIssues]
        self, **params: Unpack["InboundTransferCancelParams"]
    ) -> "InboundTransfer":
        """
        Cancels an InboundTransfer.
        """
        return cast(
            "InboundTransfer",
            await self._request_async(
                "post",
                "/v1/treasury/inbound_transfers/{inbound_transfer}/cancel".format(
                    inbound_transfer=sanitize_id(self.get("id"))
                ),
                params=params,
            ),
        )

    @classmethod
    def create(
        cls, **params: Unpack["InboundTransferCreateParams"]
    ) -> "InboundTransfer":
        """
        Creates an InboundTransfer.
        """
        return cast(
            "InboundTransfer",
            cls._static_request(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    @classmethod
    async def create_async(
        cls, **params: Unpack["InboundTransferCreateParams"]
    ) -> "InboundTransfer":
        """
        Creates an InboundTransfer.
        """
        return cast(
            "InboundTransfer",
            await cls._static_request_async(
                "post",
                cls.class_url(),
                params=params,
            ),
        )

    @classmethod
    def list(
        cls, **params: Unpack["InboundTransferListParams"]
    ) -> ListObject["InboundTransfer"]:
        """
        Returns a list of InboundTransfers sent from the specified FinancialAccount.
        """
        result = cls._static_request(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    async def list_async(
        cls, **params: Unpack["InboundTransferListParams"]
    ) -> ListObject["InboundTransfer"]:
        """
        Returns a list of InboundTransfers sent from the specified FinancialAccount.
        """
        result = await cls._static_request_async(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    def retrieve(
        cls, id: str, **params: Unpack["InboundTransferRetrieveParams"]
    ) -> "InboundTransfer":
        """
        Retrieves the details of an existing InboundTransfer.
        """
        instance = cls(id, **params)
        instance.refresh()
        return instance

    @classmethod
    async def retrieve_async(
        cls, id: str, **params: Unpack["InboundTransferRetrieveParams"]
    ) -> "InboundTransfer":
        """
        Retrieves the details of an existing InboundTransfer.
        """
        instance = cls(id, **params)
        await instance.refresh_async()
        return instance

    class TestHelpers(APIResourceTestHelpers["InboundTransfer"]):
        _resource_cls: Type["InboundTransfer"]

        @classmethod
        def _cls_fail(
            cls, id: str, **params: Unpack["InboundTransferFailParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the failed status. The InboundTransfer must already be in the processing state.
            """
            return cast(
                "InboundTransfer",
                cls._static_request(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/fail".format(
                        id=sanitize_id(id)
                    ),
                    params=params,
                ),
            )

        @overload
        @staticmethod
        def fail(
            id: str, **params: Unpack["InboundTransferFailParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the failed status. The InboundTransfer must already be in the processing state.
            """
            ...

        @overload
        def fail(
            self, **params: Unpack["InboundTransferFailParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the failed status. The InboundTransfer must already be in the processing state.
            """
            ...

        @class_method_variant("_cls_fail")
        def fail(  # pyright: ignore[reportGeneralTypeIssues]
            self, **params: Unpack["InboundTransferFailParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the failed status. The InboundTransfer must already be in the processing state.
            """
            return cast(
                "InboundTransfer",
                self.resource._request(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/fail".format(
                        id=sanitize_id(self.resource.get("id"))
                    ),
                    params=params,
                ),
            )

        @classmethod
        async def _cls_fail_async(
            cls, id: str, **params: Unpack["InboundTransferFailParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the failed status. The InboundTransfer must already be in the processing state.
            """
            return cast(
                "InboundTransfer",
                await cls._static_request_async(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/fail".format(
                        id=sanitize_id(id)
                    ),
                    params=params,
                ),
            )

        @overload
        @staticmethod
        async def fail_async(
            id: str, **params: Unpack["InboundTransferFailParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the failed status. The InboundTransfer must already be in the processing state.
            """
            ...

        @overload
        async def fail_async(
            self, **params: Unpack["InboundTransferFailParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the failed status. The InboundTransfer must already be in the processing state.
            """
            ...

        @class_method_variant("_cls_fail_async")
        async def fail_async(  # pyright: ignore[reportGeneralTypeIssues]
            self, **params: Unpack["InboundTransferFailParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the failed status. The InboundTransfer must already be in the processing state.
            """
            return cast(
                "InboundTransfer",
                await self.resource._request_async(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/fail".format(
                        id=sanitize_id(self.resource.get("id"))
                    ),
                    params=params,
                ),
            )

        @classmethod
        def _cls_return_inbound_transfer(
            cls,
            id: str,
            **params: Unpack["InboundTransferReturnInboundTransferParams"],
        ) -> "InboundTransfer":
            """
            Marks the test mode InboundTransfer object as returned and links the InboundTransfer to a ReceivedDebit. The InboundTransfer must already be in the succeeded state.
            """
            return cast(
                "InboundTransfer",
                cls._static_request(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/return".format(
                        id=sanitize_id(id)
                    ),
                    params=params,
                ),
            )

        @overload
        @staticmethod
        def return_inbound_transfer(
            id: str,
            **params: Unpack["InboundTransferReturnInboundTransferParams"],
        ) -> "InboundTransfer":
            """
            Marks the test mode InboundTransfer object as returned and links the InboundTransfer to a ReceivedDebit. The InboundTransfer must already be in the succeeded state.
            """
            ...

        @overload
        def return_inbound_transfer(
            self,
            **params: Unpack["InboundTransferReturnInboundTransferParams"],
        ) -> "InboundTransfer":
            """
            Marks the test mode InboundTransfer object as returned and links the InboundTransfer to a ReceivedDebit. The InboundTransfer must already be in the succeeded state.
            """
            ...

        @class_method_variant("_cls_return_inbound_transfer")
        def return_inbound_transfer(  # pyright: ignore[reportGeneralTypeIssues]
            self,
            **params: Unpack["InboundTransferReturnInboundTransferParams"],
        ) -> "InboundTransfer":
            """
            Marks the test mode InboundTransfer object as returned and links the InboundTransfer to a ReceivedDebit. The InboundTransfer must already be in the succeeded state.
            """
            return cast(
                "InboundTransfer",
                self.resource._request(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/return".format(
                        id=sanitize_id(self.resource.get("id"))
                    ),
                    params=params,
                ),
            )

        @classmethod
        async def _cls_return_inbound_transfer_async(
            cls,
            id: str,
            **params: Unpack["InboundTransferReturnInboundTransferParams"],
        ) -> "InboundTransfer":
            """
            Marks the test mode InboundTransfer object as returned and links the InboundTransfer to a ReceivedDebit. The InboundTransfer must already be in the succeeded state.
            """
            return cast(
                "InboundTransfer",
                await cls._static_request_async(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/return".format(
                        id=sanitize_id(id)
                    ),
                    params=params,
                ),
            )

        @overload
        @staticmethod
        async def return_inbound_transfer_async(
            id: str,
            **params: Unpack["InboundTransferReturnInboundTransferParams"],
        ) -> "InboundTransfer":
            """
            Marks the test mode InboundTransfer object as returned and links the InboundTransfer to a ReceivedDebit. The InboundTransfer must already be in the succeeded state.
            """
            ...

        @overload
        async def return_inbound_transfer_async(
            self,
            **params: Unpack["InboundTransferReturnInboundTransferParams"],
        ) -> "InboundTransfer":
            """
            Marks the test mode InboundTransfer object as returned and links the InboundTransfer to a ReceivedDebit. The InboundTransfer must already be in the succeeded state.
            """
            ...

        @class_method_variant("_cls_return_inbound_transfer_async")
        async def return_inbound_transfer_async(  # pyright: ignore[reportGeneralTypeIssues]
            self,
            **params: Unpack["InboundTransferReturnInboundTransferParams"],
        ) -> "InboundTransfer":
            """
            Marks the test mode InboundTransfer object as returned and links the InboundTransfer to a ReceivedDebit. The InboundTransfer must already be in the succeeded state.
            """
            return cast(
                "InboundTransfer",
                await self.resource._request_async(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/return".format(
                        id=sanitize_id(self.resource.get("id"))
                    ),
                    params=params,
                ),
            )

        @classmethod
        def _cls_succeed(
            cls, id: str, **params: Unpack["InboundTransferSucceedParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the succeeded status. The InboundTransfer must already be in the processing state.
            """
            return cast(
                "InboundTransfer",
                cls._static_request(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/succeed".format(
                        id=sanitize_id(id)
                    ),
                    params=params,
                ),
            )

        @overload
        @staticmethod
        def succeed(
            id: str, **params: Unpack["InboundTransferSucceedParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the succeeded status. The InboundTransfer must already be in the processing state.
            """
            ...

        @overload
        def succeed(
            self, **params: Unpack["InboundTransferSucceedParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the succeeded status. The InboundTransfer must already be in the processing state.
            """
            ...

        @class_method_variant("_cls_succeed")
        def succeed(  # pyright: ignore[reportGeneralTypeIssues]
            self, **params: Unpack["InboundTransferSucceedParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the succeeded status. The InboundTransfer must already be in the processing state.
            """
            return cast(
                "InboundTransfer",
                self.resource._request(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/succeed".format(
                        id=sanitize_id(self.resource.get("id"))
                    ),
                    params=params,
                ),
            )

        @classmethod
        async def _cls_succeed_async(
            cls, id: str, **params: Unpack["InboundTransferSucceedParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the succeeded status. The InboundTransfer must already be in the processing state.
            """
            return cast(
                "InboundTransfer",
                await cls._static_request_async(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/succeed".format(
                        id=sanitize_id(id)
                    ),
                    params=params,
                ),
            )

        @overload
        @staticmethod
        async def succeed_async(
            id: str, **params: Unpack["InboundTransferSucceedParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the succeeded status. The InboundTransfer must already be in the processing state.
            """
            ...

        @overload
        async def succeed_async(
            self, **params: Unpack["InboundTransferSucceedParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the succeeded status. The InboundTransfer must already be in the processing state.
            """
            ...

        @class_method_variant("_cls_succeed_async")
        async def succeed_async(  # pyright: ignore[reportGeneralTypeIssues]
            self, **params: Unpack["InboundTransferSucceedParams"]
        ) -> "InboundTransfer":
            """
            Transitions a test mode created InboundTransfer to the succeeded status. The InboundTransfer must already be in the processing state.
            """
            return cast(
                "InboundTransfer",
                await self.resource._request_async(
                    "post",
                    "/v1/test_helpers/treasury/inbound_transfers/{id}/succeed".format(
                        id=sanitize_id(self.resource.get("id"))
                    ),
                    params=params,
                ),
            )

    @property
    def test_helpers(self):
        return self.TestHelpers(self)

    _inner_class_types = {
        "failure_details": FailureDetails,
        "linked_flows": LinkedFlows,
        "origin_payment_method_details": OriginPaymentMethodDetails,
        "status_transitions": StatusTransitions,
    }


InboundTransfer.TestHelpers._resource_cls = InboundTransfer



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._expandable_field import ExpandableField
from stripe._list_object import ListObject
from stripe._listable_api_resource import ListableAPIResource
from stripe._stripe_object import StripeObject
from typing import ClassVar, List, Optional
from typing_extensions import Literal, Unpack, TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.identity._blocklist_entry import BlocklistEntry
    from stripe.params.identity._verification_report_list_params import (
        VerificationReportListParams,
    )
    from stripe.params.identity._verification_report_retrieve_params import (
        VerificationReportRetrieveParams,
    )


class VerificationReport(ListableAPIResource["VerificationReport"]):
    """
    A VerificationReport is the result of an attempt to collect and verify data from a user.
    The collection of verification checks performed is determined from the `type` and `options`
    parameters used. You can find the result of each verification check performed in the
    appropriate sub-resource: `document`, `id_number`, `selfie`.

    Each VerificationReport contains a copy of any data collected by the user as well as
    reference IDs which can be used to access collected images through the [FileUpload](https://docs.stripe.com/api/files)
    API. To configure and create VerificationReports, use the
    [VerificationSession](https://docs.stripe.com/api/identity/verification_sessions) API.

    Related guide: [Accessing verification results](https://docs.stripe.com/identity/verification-sessions#results).
    """

    OBJECT_NAME: ClassVar[Literal["identity.verification_report"]] = (
        "identity.verification_report"
    )

    class Document(StripeObject):
        class Address(StripeObject):
            city: Optional[str]
            """
            City, district, suburb, town, or village.
            """
            country: Optional[str]
            """
            Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
            """
            line1: Optional[str]
            """
            Address line 1, such as the street, PO Box, or company name.
            """
            line2: Optional[str]
            """
            Address line 2, such as the apartment, suite, unit, or building.
            """
            postal_code: Optional[str]
            """
            ZIP or postal code.
            """
            state: Optional[str]
            """
            State, county, province, or region ([ISO 3166-2](https://en.wikipedia.org/wiki/ISO_3166-2)).
            """

        class Dob(StripeObject):
            day: Optional[int]
            """
            Numerical day between 1 and 31.
            """
            month: Optional[int]
            """
            Numerical month between 1 and 12.
            """
            year: Optional[int]
            """
            The four-digit year.
            """

        class Error(StripeObject):
            code: Optional[
                Literal[
                    "document_expired",
                    "document_type_not_supported",
                    "document_unverified_other",
                ]
            ]
            """
            A short machine-readable string giving the reason for the verification failure.
            """
            reason: Optional[str]
            """
            A human-readable message giving the reason for the failure. These messages can be shown to your users.
            """

        class ExpirationDate(StripeObject):
            day: Optional[int]
            """
            Numerical day between 1 and 31.
            """
            month: Optional[int]
            """
            Numerical month between 1 and 12.
            """
            year: Optional[int]
            """
            The four-digit year.
            """

        class IssuedDate(StripeObject):
            day: Optional[int]
            """
            Numerical day between 1 and 31.
            """
            month: Optional[int]
            """
            Numerical month between 1 and 12.
            """
            year: Optional[int]
            """
            The four-digit year.
            """

        address: Optional[Address]
        """
        Address as it appears in the document.
        """
        blocked_by_entry: Optional[ExpandableField["BlocklistEntry"]]
        """
        If document was not verified due to extracted data being on the blocklist, this is the token of the BlocklistEntry that blocked it
        """
        dob: Optional[Dob]
        """
        Date of birth as it appears in the document.
        """
        error: Optional[Error]
        """
        Details on the verification error. Present when status is `unverified`.
        """
        expiration_date: Optional[ExpirationDate]
        """
        Expiration date of the document.
        """
        files: Optional[List[str]]
        """
        Array of [File](https://docs.stripe.com/api/files) ids containing images for this document.
        """
        first_name: Optional[str]
        """
        First name as it appears in the document.
        """
        issued_date: Optional[IssuedDate]
        """
        Issued date of the document.
        """
        issuing_country: Optional[str]
        """
        Issuing country of the document.
        """
        last_name: Optional[str]
        """
        Last name as it appears in the document.
        """
        number: Optional[str]
        """
        Document ID number.
        """
        sex: Optional[Literal["[redacted]", "female", "male", "unknown"]]
        """
        Sex of the person in the document.
        """
        status: Literal["unverified", "verified"]
        """
        Status of this `document` check.
        """
        type: Optional[Literal["driving_license", "id_card", "passport"]]
        """
        Type of the document.
        """
        unparsed_place_of_birth: Optional[str]
        """
        Place of birth as it appears in the document.
        """
        unparsed_sex: Optional[str]
        """
        Sex as it appears in the document.
        """
        _inner_class_types = {
            "address": Address,
            "dob": Dob,
            "error": Error,
            "expiration_date": ExpirationDate,
            "issued_date": IssuedDate,
        }

    class Email(StripeObject):
        class Error(StripeObject):
            code: Optional[
                Literal[
                    "email_unverified_other", "email_verification_declined"
                ]
            ]
            """
            A short machine-readable string giving the reason for the verification failure.
            """
            reason: Optional[str]
            """
            A human-readable message giving the reason for the failure. These messages can be shown to your users.
            """

        email: Optional[str]
        """
        Email to be verified.
        """
        error: Optional[Error]
        """
        Details on the verification error. Present when status is `unverified`.
        """
        status: Literal["unverified", "verified"]
        """
        Status of this `email` check.
        """
        _inner_class_types = {"error": Error}

    class IdNumber(StripeObject):
        class Dob(StripeObject):
            day: Optional[int]
            """
            Numerical day between 1 and 31.
            """
            month: Optional[int]
            """
            Numerical month between 1 and 12.
            """
            year: Optional[int]
            """
            The four-digit year.
            """

        class Error(StripeObject):
            code: Optional[
                Literal[
                    "id_number_insufficient_document_data",
                    "id_number_mismatch",
                    "id_number_unverified_other",
                ]
            ]
            """
            A short machine-readable string giving the reason for the verification failure.
            """
            reason: Optional[str]
            """
            A human-readable message giving the reason for the failure. These messages can be shown to your users.
            """

        dob: Optional[Dob]
        """
        Date of birth.
        """
        error: Optional[Error]
        """
        Details on the verification error. Present when status is `unverified`.
        """
        first_name: Optional[str]
        """
        First name.
        """
        id_number: Optional[str]
        """
        ID number. When `id_number_type` is `us_ssn`, only the last 4 digits are present.
        """
        id_number_type: Optional[Literal["br_cpf", "sg_nric", "us_ssn"]]
        """
        Type of ID number.
        """
        last_name: Optional[str]
        """
        Last name.
        """
        status: Literal["unverified", "verified"]
        """
        Status of this `id_number` check.
        """
        _inner_class_types = {"dob": Dob, "error": Error}

    class Options(StripeObject):
        class Document(StripeObject):
            allowed_types: Optional[
                List[Literal["driving_license", "id_card", "passport"]]
            ]
            """
            Array of strings of allowed identity document types. If the provided identity document isn't one of the allowed types, the verification check will fail with a document_type_not_allowed error code.
            """
            require_id_number: Optional[bool]
            """
            Collect an ID number and perform an [ID number check](https://docs.stripe.com/identity/verification-checks?type=id-number) with the document's extracted name and date of birth.
            """
            require_live_capture: Optional[bool]
            """
            Disable image uploads, identity document images have to be captured using the device's camera.
            """
            require_matching_selfie: Optional[bool]
            """
            Capture a face image and perform a [selfie check](https://docs.stripe.com/identity/verification-checks?type=selfie) comparing a photo ID and a picture of your user's face. [Learn more](https://docs.stripe.com/identity/selfie).
            """

        class IdNumber(StripeObject):
            pass

        document: Optional[Document]
        id_number: Optional[IdNumber]
        _inner_class_types = {"document": Document, "id_number": IdNumber}

    class Phone(StripeObject):
        class Error(StripeObject):
            code: Optional[
                Literal[
                    "phone_unverified_other", "phone_verification_declined"
                ]
            ]
            """
            A short machine-readable string giving the reason for the verification failure.
            """
            reason: Optional[str]
            """
            A human-readable message giving the reason for the failure. These messages can be shown to your users.
            """

        error: Optional[Error]
        """
        Details on the verification error. Present when status is `unverified`.
        """
        phone: Optional[str]
        """
        Phone to be verified.
        """
        status: Literal["unverified", "verified"]
        """
        Status of this `phone` check.
        """
        _inner_class_types = {"error": Error}

    class Selfie(StripeObject):
        class Error(StripeObject):
            code: Optional[
                Literal[
                    "selfie_document_missing_photo",
                    "selfie_face_mismatch",
                    "selfie_manipulated",
                    "selfie_unverified_other",
                ]
            ]
            """
            A short machine-readable string giving the reason for the verification failure.
            """
            reason: Optional[str]
            """
            A human-readable message giving the reason for the failure. These messages can be shown to your users.
            """

        blocked_by_entry: Optional[ExpandableField["BlocklistEntry"]]
        """
        If selfie was not verified due to being on the blocklist, this is the token of the BlocklistEntry that blocked it
        """
        document: Optional[str]
        """
        ID of the [File](https://docs.stripe.com/api/files) holding the image of the identity document used in this check.
        """
        error: Optional[Error]
        """
        Details on the verification error. Present when status is `unverified`.
        """
        selfie: Optional[str]
        """
        ID of the [File](https://docs.stripe.com/api/files) holding the image of the selfie used in this check.
        """
        status: Literal["unverified", "verified"]
        """
        Status of this `selfie` check.
        """
        _inner_class_types = {"error": Error}

    client_reference_id: Optional[str]
    """
    A string to reference this user. This can be a customer ID, a session ID, or similar, and can be used to reconcile this verification with your internal systems.
    """
    created: int
    """
    Time at which the object was created. Measured in seconds since the Unix epoch.
    """
    document: Optional[Document]
    """
    Result from a document check
    """
    email: Optional[Email]
    """
    Result from a email check
    """
    id: str
    """
    Unique identifier for the object.
    """
    id_number: Optional[IdNumber]
    """
    Result from an id_number check
    """
    livemode: bool
    """
    Has the value `true` if the object exists in live mode or the value `false` if the object exists in test mode.
    """
    object: Literal["identity.verification_report"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """
    options: Optional[Options]
    phone: Optional[Phone]
    """
    Result from a phone check
    """
    selfie: Optional[Selfie]
    """
    Result from a selfie check
    """
    type: Literal["document", "id_number", "verification_flow"]
    """
    Type of report.
    """
    verification_flow: Optional[str]
    """
    The configuration token of a verification flow from the dashboard.
    """
    verification_session: Optional[str]
    """
    ID of the VerificationSession that created this report.
    """

    @classmethod
    def list(
        cls, **params: Unpack["VerificationReportListParams"]
    ) -> ListObject["VerificationReport"]:
        """
        List all verification reports.
        """
        result = cls._static_request(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    async def list_async(
        cls, **params: Unpack["VerificationReportListParams"]
    ) -> ListObject["VerificationReport"]:
        """
        List all verification reports.
        """
        result = await cls._static_request_async(
            "get",
            cls.class_url(),
            params=params,
        )
        if not isinstance(result, ListObject):
            raise TypeError(
                "Expected list object from API, got %s"
                % (type(result).__name__)
            )

        return result

    @classmethod
    def retrieve(
        cls, id: str, **params: Unpack["VerificationReportRetrieveParams"]
    ) -> "VerificationReport":
        """
        Retrieves an existing VerificationReport
        """
        instance = cls(id, **params)
        instance.refresh()
        return instance

    @classmethod
    async def retrieve_async(
        cls, id: str, **params: Unpack["VerificationReportRetrieveParams"]
    ) -> "VerificationReport":
        """
        Retrieves an existing VerificationReport
        """
        instance = cls(id, **params)
        await instance.refresh_async()
        return instance

    _inner_class_types = {
        "document": Document,
        "email": Email,
        "id_number": IdNumber,
        "options": Options,
        "phone": Phone,
        "selfie": Selfie,
    }



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_object import StripeObject
from typing import ClassVar, Dict, List, Optional
from typing_extensions import Literal


class CalculationLineItem(StripeObject):
    OBJECT_NAME: ClassVar[Literal["tax.calculation_line_item"]] = (
        "tax.calculation_line_item"
    )

    class TaxBreakdown(StripeObject):
        class Jurisdiction(StripeObject):
            country: str
            """
            Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
            """
            display_name: str
            """
            A human-readable name for the jurisdiction imposing the tax.
            """
            level: Literal["city", "country", "county", "district", "state"]
            """
            Indicates the level of the jurisdiction imposing the tax.
            """
            state: Optional[str]
            """
            [ISO 3166-2 subdivision code](https://en.wikipedia.org/wiki/ISO_3166-2), without country prefix. For example, "NY" for New York, United States.
            """

        class TaxRateDetails(StripeObject):
            display_name: str
            """
            A localized display name for tax type, intended to be human-readable. For example, "Local Sales and Use Tax", "Value-added tax (VAT)", or "Umsatzsteuer (USt.)".
            """
            percentage_decimal: str
            """
            The tax rate percentage as a string. For example, 8.5% is represented as "8.5".
            """
            tax_type: Literal[
                "admissions_tax",
                "amusement_tax",
                "attendance_tax",
                "communications_tax",
                "entertainment_tax",
                "gross_receipts_tax",
                "gst",
                "hospitality_tax",
                "hst",
                "igst",
                "jct",
                "lease_tax",
                "luxury_tax",
                "pst",
                "qst",
                "resort_tax",
                "retail_delivery_fee",
                "rst",
                "sales_tax",
                "service_tax",
                "tourism_tax",
                "vat",
            ]
            """
            The tax type, such as `vat` or `sales_tax`.
            """

        amount: int
        """
        The amount of tax, in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).
        """
        jurisdiction: Jurisdiction
        sourcing: Literal["destination", "origin", "performance"]
        """
        Indicates whether the jurisdiction was determined by the origin (merchant's address) or destination (customer's address).
        """
        tax_rate_details: Optional[TaxRateDetails]
        """
        Details regarding the rate for this tax. This field will be `null` when the tax is not imposed, for example if the product is exempt from tax.
        """
        taxability_reason: Literal[
            "customer_exempt",
            "not_collecting",
            "not_subject_to_tax",
            "not_supported",
            "portion_product_exempt",
            "portion_reduced_rated",
            "portion_standard_rated",
            "product_exempt",
            "product_exempt_holiday",
            "proportionally_rated",
            "reduced_rated",
            "reverse_charge",
            "standard_rated",
            "taxable_basis_reduced",
            "zero_rated",
        ]
        """
        The reasoning behind this tax, for example, if the product is tax exempt. The possible values for this field may be extended as new tax rules are supported.
        """
        taxable_amount: int
        """
        The amount on which tax is calculated, in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).
        """
        _inner_class_types = {
            "jurisdiction": Jurisdiction,
            "tax_rate_details": TaxRateDetails,
        }

    amount: int
    """
    The line item amount in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal). If `tax_behavior=inclusive`, then this amount includes taxes. Otherwise, taxes were calculated on top of this amount.
    """
    amount_tax: int
    """
    The amount of tax calculated for this line item, in the [smallest currency unit](https://docs.stripe.com/currencies#zero-decimal).
    """
    id: str
    """
    Unique identifier for the object.
    """
    livemode: bool
    """
    Has the value `true` if the object exists in live mode or the value `false` if the object exists in test mode.
    """
    metadata: Optional[Dict[str, str]]
    """
    Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
    """
    object: Literal["tax.calculation_line_item"]
    """
    String representing the object's type. Objects of the same type share the same value.
    """
    performance_location: Optional[str]
    """
    A tax location for a line item that acts as a performance location. This indicates that the line item might be taxed at the place where it is being performed at. This is helpful for events or other services being performed at non-customer addresses like venues or offices. This can be left empty for tax codes that do not require a tax location. For tax codes where the location requirement is "optional", this would override the customer address in most use cases.
    """
    product: Optional[str]
    """
    The ID of an existing [Product](https://docs.stripe.com/api/products/object).
    """
    quantity: int
    """
    The number of units of the item being purchased. For reversals, this is the quantity reversed.
    """
    reference: str
    """
    A custom identifier for this line item.
    """
    tax_behavior: Literal["exclusive", "inclusive"]
    """
    Specifies whether the `amount` includes taxes. If `tax_behavior=inclusive`, then the amount includes taxes.
    """
    tax_breakdown: Optional[List[TaxBreakdown]]
    """
    Detailed account of taxes relevant to this line item.
    """
    tax_code: str
    """
    The [tax code](https://docs.stripe.com/tax/tax-categories) ID used for this resource.
    """
    _inner_class_types = {"tax_breakdown": TaxBreakdown}



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._list_object import ListObject
    from stripe._request_options import RequestOptions
    from stripe.params.treasury._financial_account_close_params import (
        FinancialAccountCloseParams,
    )
    from stripe.params.treasury._financial_account_create_params import (
        FinancialAccountCreateParams,
    )
    from stripe.params.treasury._financial_account_list_params import (
        FinancialAccountListParams,
    )
    from stripe.params.treasury._financial_account_retrieve_params import (
        FinancialAccountRetrieveParams,
    )
    from stripe.params.treasury._financial_account_update_params import (
        FinancialAccountUpdateParams,
    )
    from stripe.treasury._financial_account import FinancialAccount
    from stripe.treasury._financial_account_features_service import (
        FinancialAccountFeaturesService,
    )

_subservices = {
    "features": [
        "stripe.treasury._financial_account_features_service",
        "FinancialAccountFeaturesService",
    ],
}


class FinancialAccountService(StripeService):
    features: "FinancialAccountFeaturesService"

    def __init__(self, requestor):
        super().__init__(requestor)

    def __getattr__(self, name):
        try:
            import_from, service = _subservices[name]
            service_class = getattr(
                import_module(import_from),
                service,
            )
            setattr(
                self,
                name,
                service_class(self._requestor),
            )
            return getattr(self, name)
        except KeyError:
            raise AttributeError()

    def list(
        self,
        params: Optional["FinancialAccountListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[FinancialAccount]":
        """
        Returns a list of FinancialAccounts.
        """
        return cast(
            "ListObject[FinancialAccount]",
            self._request(
                "get",
                "/v1/treasury/financial_accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["FinancialAccountListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[FinancialAccount]":
        """
        Returns a list of FinancialAccounts.
        """
        return cast(
            "ListObject[FinancialAccount]",
            await self._request_async(
                "get",
                "/v1/treasury/financial_accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: "FinancialAccountCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "FinancialAccount":
        """
        Creates a new FinancialAccount. Each connected account can have up to three FinancialAccounts by default.
        """
        return cast(
            "FinancialAccount",
            self._request(
                "post",
                "/v1/treasury/financial_accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "FinancialAccountCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "FinancialAccount":
        """
        Creates a new FinancialAccount. Each connected account can have up to three FinancialAccounts by default.
        """
        return cast(
            "FinancialAccount",
            await self._request_async(
                "post",
                "/v1/treasury/financial_accounts",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        financial_account: str,
        params: Optional["FinancialAccountRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "FinancialAccount":
        """
        Retrieves the details of a FinancialAccount.
        """
        return cast(
            "FinancialAccount",
            self._request(
                "get",
                "/v1/treasury/financial_accounts/{financial_account}".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        financial_account: str,
        params: Optional["FinancialAccountRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "FinancialAccount":
        """
        Retrieves the details of a FinancialAccount.
        """
        return cast(
            "FinancialAccount",
            await self._request_async(
                "get",
                "/v1/treasury/financial_accounts/{financial_account}".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def update(
        self,
        financial_account: str,
        params: Optional["FinancialAccountUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "FinancialAccount":
        """
        Updates the details of a FinancialAccount.
        """
        return cast(
            "FinancialAccount",
            self._request(
                "post",
                "/v1/treasury/financial_accounts/{financial_account}".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def update_async(
        self,
        financial_account: str,
        params: Optional["FinancialAccountUpdateParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "FinancialAccount":
        """
        Updates the details of a FinancialAccount.
        """
        return cast(
            "FinancialAccount",
            await self._request_async(
                "post",
                "/v1/treasury/financial_accounts/{financial_account}".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def close(
        self,
        financial_account: str,
        params: Optional["FinancialAccountCloseParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "FinancialAccount":
        """
        Closes a FinancialAccount. A FinancialAccount can only be closed if it has a zero balance, has no pending InboundTransfers, and has canceled all attached Issuing cards.
        """
        return cast(
            "FinancialAccount",
            self._request(
                "post",
                "/v1/treasury/financial_accounts/{financial_account}/close".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def close_async(
        self,
        financial_account: str,
        params: Optional["FinancialAccountCloseParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "FinancialAccount":
        """
        Closes a FinancialAccount. A FinancialAccount can only be closed if it has a zero balance, has no pending InboundTransfers, and has canceled all attached Issuing cards.
        """
        return cast(
            "FinancialAccount",
            await self._request_async(
                "post",
                "/v1/treasury/financial_accounts/{financial_account}/close".format(
                    financial_account=sanitize_id(financial_account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import Dict
from typing_extensions import Literal, NotRequired, TypedDict


class SplitCreateParams(TypedDict):
    account: str
    """
    The target account for settling the SettlementAllocationIntentSplit.
    """
    amount: "SplitCreateParamsAmount"
    """
    The amount and currency of the SettlementAllocationIntentSplit.
    """
    metadata: NotRequired[Dict[str, str]]
    """
    Metadata associated with the SettlementAllocationIntentSplit.
    """
    type: Literal["credit", "debit"]
    """
    The type of the fund transfer.
    """


class SplitCreateParamsAmount(TypedDict):
    value: NotRequired[int]
    """
    A non-negative integer representing how much to charge in the [smallest currency unit](https://docs.stripe.com/currencies#minor-units).
    """
    currency: NotRequired[str]
    """
    Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import List
from typing_extensions import Literal, NotRequired, TypedDict


class ConfigurationUpdateParams(TypedDict):
    bbpos_wisepad3: NotRequired[
        "Literal['']|ConfigurationUpdateParamsBbposWisepad3"
    ]
    """
    An object containing device type specific settings for BBPOS WisePad 3 readers.
    """
    bbpos_wisepos_e: NotRequired[
        "Literal['']|ConfigurationUpdateParamsBbposWiseposE"
    ]
    """
    An object containing device type specific settings for BBPOS WisePOS E readers.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    name: NotRequired[str]
    """
    Name of the configuration
    """
    offline: NotRequired["Literal['']|ConfigurationUpdateParamsOffline"]
    """
    Configurations for collecting transactions offline.
    """
    reader_security: NotRequired[
        "Literal['']|ConfigurationUpdateParamsReaderSecurity"
    ]
    """
    Configurations for reader security settings.
    """
    reboot_window: NotRequired[
        "Literal['']|ConfigurationUpdateParamsRebootWindow"
    ]
    """
    Reboot time settings for readers. that support customized reboot time configuration.
    """
    stripe_s700: NotRequired["Literal['']|ConfigurationUpdateParamsStripeS700"]
    """
    An object containing device type specific settings for Stripe S700 readers.
    """
    tipping: NotRequired["Literal['']|ConfigurationUpdateParamsTipping"]
    """
    Tipping configurations for readers. supporting on-reader tips
    """
    verifone_p400: NotRequired[
        "Literal['']|ConfigurationUpdateParamsVerifoneP400"
    ]
    """
    An object containing device type specific settings for Verifone P400 readers.
    """
    wifi: NotRequired["Literal['']|ConfigurationUpdateParamsWifi"]
    """
    Configurations for connecting to a WiFi network.
    """


class ConfigurationUpdateParamsBbposWisepad3(TypedDict):
    splashscreen: NotRequired["Literal['']|str"]
    """
    A File ID representing an image you want to display on the reader.
    """


class ConfigurationUpdateParamsBbposWiseposE(TypedDict):
    splashscreen: NotRequired["Literal['']|str"]
    """
    A File ID representing an image to display on the reader
    """


class ConfigurationUpdateParamsOffline(TypedDict):
    enabled: bool
    """
    Determines whether to allow transactions to be collected while reader is offline. Defaults to false.
    """


class ConfigurationUpdateParamsReaderSecurity(TypedDict):
    admin_menu_passcode: NotRequired["Literal['']|str"]
    """
    Passcode used to access a reader's admin menu.
    """


class ConfigurationUpdateParamsRebootWindow(TypedDict):
    end_hour: int
    """
    Integer between 0 to 23 that represents the end hour of the reboot time window. The value must be different than the start_hour.
    """
    start_hour: int
    """
    Integer between 0 to 23 that represents the start hour of the reboot time window.
    """


class ConfigurationUpdateParamsStripeS700(TypedDict):
    splashscreen: NotRequired["Literal['']|str"]
    """
    A File ID representing an image you want to display on the reader.
    """


class ConfigurationUpdateParamsTipping(TypedDict):
    aed: NotRequired["ConfigurationUpdateParamsTippingAed"]
    """
    Tipping configuration for AED
    """
    aud: NotRequired["ConfigurationUpdateParamsTippingAud"]
    """
    Tipping configuration for AUD
    """
    bgn: NotRequired["ConfigurationUpdateParamsTippingBgn"]
    """
    Tipping configuration for BGN
    """
    cad: NotRequired["ConfigurationUpdateParamsTippingCad"]
    """
    Tipping configuration for CAD
    """
    chf: NotRequired["ConfigurationUpdateParamsTippingChf"]
    """
    Tipping configuration for CHF
    """
    czk: NotRequired["ConfigurationUpdateParamsTippingCzk"]
    """
    Tipping configuration for CZK
    """
    dkk: NotRequired["ConfigurationUpdateParamsTippingDkk"]
    """
    Tipping configuration for DKK
    """
    eur: NotRequired["ConfigurationUpdateParamsTippingEur"]
    """
    Tipping configuration for EUR
    """
    gbp: NotRequired["ConfigurationUpdateParamsTippingGbp"]
    """
    Tipping configuration for GBP
    """
    gip: NotRequired["ConfigurationUpdateParamsTippingGip"]
    """
    Tipping configuration for GIP
    """
    hkd: NotRequired["ConfigurationUpdateParamsTippingHkd"]
    """
    Tipping configuration for HKD
    """
    huf: NotRequired["ConfigurationUpdateParamsTippingHuf"]
    """
    Tipping configuration for HUF
    """
    jpy: NotRequired["ConfigurationUpdateParamsTippingJpy"]
    """
    Tipping configuration for JPY
    """
    mxn: NotRequired["ConfigurationUpdateParamsTippingMxn"]
    """
    Tipping configuration for MXN
    """
    myr: NotRequired["ConfigurationUpdateParamsTippingMyr"]
    """
    Tipping configuration for MYR
    """
    nok: NotRequired["ConfigurationUpdateParamsTippingNok"]
    """
    Tipping configuration for NOK
    """
    nzd: NotRequired["ConfigurationUpdateParamsTippingNzd"]
    """
    Tipping configuration for NZD
    """
    pln: NotRequired["ConfigurationUpdateParamsTippingPln"]
    """
    Tipping configuration for PLN
    """
    ron: NotRequired["ConfigurationUpdateParamsTippingRon"]
    """
    Tipping configuration for RON
    """
    sek: NotRequired["ConfigurationUpdateParamsTippingSek"]
    """
    Tipping configuration for SEK
    """
    sgd: NotRequired["ConfigurationUpdateParamsTippingSgd"]
    """
    Tipping configuration for SGD
    """
    usd: NotRequired["ConfigurationUpdateParamsTippingUsd"]
    """
    Tipping configuration for USD
    """


class ConfigurationUpdateParamsTippingAed(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingAud(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingBgn(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingCad(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingChf(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingCzk(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingDkk(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingEur(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingGbp(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingGip(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingHkd(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingHuf(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingJpy(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingMxn(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingMyr(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingNok(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingNzd(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingPln(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingRon(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingSek(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingSgd(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsTippingUsd(TypedDict):
    fixed_amounts: NotRequired[List[int]]
    """
    Fixed amounts displayed when collecting a tip
    """
    percentages: NotRequired[List[int]]
    """
    Percentages displayed when collecting a tip
    """
    smart_tip_threshold: NotRequired[int]
    """
    Below this amount, fixed amounts will be displayed; above it, percentages will be displayed
    """


class ConfigurationUpdateParamsVerifoneP400(TypedDict):
    splashscreen: NotRequired["Literal['']|str"]
    """
    A File ID representing an image you want to display on the reader.
    """


class ConfigurationUpdateParamsWifi(TypedDict):
    enterprise_eap_peap: NotRequired[
        "ConfigurationUpdateParamsWifiEnterpriseEapPeap"
    ]
    """
    Credentials for a WPA-Enterprise WiFi network using the EAP-PEAP authentication method.
    """
    enterprise_eap_tls: NotRequired[
        "ConfigurationUpdateParamsWifiEnterpriseEapTls"
    ]
    """
    Credentials for a WPA-Enterprise WiFi network using the EAP-TLS authentication method.
    """
    personal_psk: NotRequired["ConfigurationUpdateParamsWifiPersonalPsk"]
    """
    Credentials for a WPA-Personal WiFi network.
    """
    type: Literal["enterprise_eap_peap", "enterprise_eap_tls", "personal_psk"]
    """
    Security type of the WiFi network. Fill out the hash with the corresponding name to provide the set of credentials for this security type.
    """


class ConfigurationUpdateParamsWifiEnterpriseEapPeap(TypedDict):
    ca_certificate_file: NotRequired[str]
    """
    A File ID representing a PEM file containing the server certificate
    """
    password: str
    """
    Password for connecting to the WiFi network
    """
    ssid: str
    """
    Name of the WiFi network
    """
    username: str
    """
    Username for connecting to the WiFi network
    """


class ConfigurationUpdateParamsWifiEnterpriseEapTls(TypedDict):
    ca_certificate_file: NotRequired[str]
    """
    A File ID representing a PEM file containing the server certificate
    """
    client_certificate_file: str
    """
    A File ID representing a PEM file containing the client certificate
    """
    private_key_file: str
    """
    A File ID representing a PEM file containing the client RSA private key
    """
    private_key_file_password: NotRequired[str]
    """
    Password for the private key file
    """
    ssid: str
    """
    Name of the WiFi network
    """


class ConfigurationUpdateParamsWifiPersonalPsk(TypedDict):
    password: str
    """
    Password for connecting to the WiFi network
    """
    ssid: str
    """
    Name of the WiFi network
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.v2.core._event import Event, EventNotification
from typing import cast
from typing_extensions import Literal, override


class V2IamApiKeyDefaultSecretRevealedEventNotification(EventNotification):
    LOOKUP_TYPE = "v2.iam.api_key.default_secret_revealed"
    type: Literal["v2.iam.api_key.default_secret_revealed"]

    @override
    def fetch_event(self) -> "V2IamApiKeyDefaultSecretRevealedEvent":
        return cast(
            "V2IamApiKeyDefaultSecretRevealedEvent",
            super().fetch_event(),
        )

    @override
    async def fetch_event_async(
        self,
    ) -> "V2IamApiKeyDefaultSecretRevealedEvent":
        return cast(
            "V2IamApiKeyDefaultSecretRevealedEvent",
            await super().fetch_event_async(),
        )


class V2IamApiKeyDefaultSecretRevealedEvent(Event):
    LOOKUP_TYPE = "v2.iam.api_key.default_secret_revealed"
    type: Literal["v2.iam.api_key.default_secret_revealed"]



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.capital._financing_offer_service import FinancingOfferService
    from stripe.capital._financing_summary_service import (
        FinancingSummaryService,
    )
    from stripe.capital._financing_transaction_service import (
        FinancingTransactionService,
    )

_subservices = {
    "financing_offers": [
        "stripe.capital._financing_offer_service",
        "FinancingOfferService",
    ],
    "financing_summary": [
        "stripe.capital._financing_summary_service",
        "FinancingSummaryService",
    ],
    "financing_transactions": [
        "stripe.capital._financing_transaction_service",
        "FinancingTransactionService",
    ],
}


class CapitalService(StripeService):
    financing_offers: "FinancingOfferService"
    financing_summary: "FinancingSummaryService"
    financing_transactions: "FinancingTransactionService"

    def __init__(self, requestor):
        super().__init__(requestor)

    def __getattr__(self, name):
        try:
            import_from, service = _subservices[name]
            service_class = getattr(
                import_module(import_from),
                service,
            )
            setattr(
                self,
                name,
                service_class(self._requestor),
            )
            return getattr(self, name)
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.v2.payments.settlement_allocation_intents._split_cancel_params import (
        SplitCancelParams as SplitCancelParams,
    )
    from stripe.params.v2.payments.settlement_allocation_intents._split_create_params import (
        SplitCreateParams as SplitCreateParams,
        SplitCreateParamsAmount as SplitCreateParamsAmount,
    )
    from stripe.params.v2.payments.settlement_allocation_intents._split_retrieve_params import (
        SplitRetrieveParams as SplitRetrieveParams,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "SplitCancelParams": (
        "stripe.params.v2.payments.settlement_allocation_intents._split_cancel_params",
        False,
    ),
    "SplitCreateParams": (
        "stripe.params.v2.payments.settlement_allocation_intents._split_create_params",
        False,
    ),
    "SplitCreateParamsAmount": (
        "stripe.params.v2.payments.settlement_allocation_intents._split_create_params",
        False,
    ),
    "SplitRetrieveParams": (
        "stripe.params.v2.payments.settlement_allocation_intents._split_retrieve_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import Dict
from typing_extensions import Literal, NotRequired, TypedDict


class OffSessionPaymentCreateParams(TypedDict):
    amount: "OffSessionPaymentCreateParamsAmount"
    """
    The “presentment amount” to be collected from the customer.
    """
    cadence: Literal["recurring", "unscheduled"]
    """
    The frequency of the underlying payment.
    """
    capture: NotRequired["OffSessionPaymentCreateParamsCapture"]
    """
    Details about the capture configuration for the OffSessionPayment.
    """
    customer: str
    """
    ID of the Customer to which this OffSessionPayment belongs.
    """
    metadata: Dict[str, str]
    """
    Set of [key-value pairs](https://docs.stripe.com/api/metadata) that you can
    attach to an object. This can be useful for storing additional information about
    the object in a structured format. Learn more about
    [storing information in metadata](https://docs.stripe.com/payments/payment-intents#storing-information-in-metadata).
    """
    on_behalf_of: NotRequired[str]
    """
    The account (if any) for which the funds of the OffSessionPayment are intended.
    """
    payment_method: str
    """
    ID of the payment method used in this OffSessionPayment.
    """
    payment_method_options: NotRequired[
        "OffSessionPaymentCreateParamsPaymentMethodOptions"
    ]
    """
    Payment method options for the off-session payment.
    """
    payments_orchestration: NotRequired[
        "OffSessionPaymentCreateParamsPaymentsOrchestration"
    ]
    """
    Details about the payments orchestration configuration.
    """
    retry_details: NotRequired["OffSessionPaymentCreateParamsRetryDetails"]
    """
    Details about the OffSessionPayment retries.
    """
    statement_descriptor: NotRequired[str]
    """
    Text that appears on the customer's statement as the statement descriptor for a
    non-card charge. This value overrides the account's default statement descriptor.
    For information about requirements, including the 22-character limit, see the
    [Statement Descriptor docs](https://docs.stripe.com/get-started/account/statement-descriptors).
    """
    statement_descriptor_suffix: NotRequired[str]
    """
    Provides information about a card charge. Concatenated to the account's
    [statement descriptor prefix](https://docs.stripe.com/get-started/account/statement-descriptors#static)
    to form the complete statement descriptor that appears on the customer's statement.
    """
    test_clock: NotRequired[str]
    """
    Test clock that can be used to advance the retry attempts in a sandbox.
    """
    transfer_data: NotRequired["OffSessionPaymentCreateParamsTransferData"]
    """
    The data that automatically creates a Transfer after the payment finalizes. Learn more about the use case for [connected accounts](https://docs.stripe.com/payments/connected-accounts).
    """


class OffSessionPaymentCreateParamsAmount(TypedDict):
    value: NotRequired[int]
    """
    A non-negative integer representing how much to charge in the [smallest currency unit](https://docs.stripe.com/currencies#minor-units).
    """
    currency: NotRequired[str]
    """
    Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """


class OffSessionPaymentCreateParamsCapture(TypedDict):
    capture_method: Literal["automatic", "manual"]
    """
    The method to use to capture the payment.
    """


class OffSessionPaymentCreateParamsPaymentMethodOptions(TypedDict):
    card: NotRequired["OffSessionPaymentCreateParamsPaymentMethodOptionsCard"]
    """
    Payment method options for the card payment type.
    """


class OffSessionPaymentCreateParamsPaymentMethodOptionsCard(TypedDict):
    network_transaction_id: str
    """
    If you are making a Credential On File transaction with a previously saved card, you should pass the Network Transaction ID
    from a prior initial authorization on Stripe (from a successful SetupIntent or a PaymentIntent with `setup_future_usage` set),
    or one that you have obtained from another payment processor. This is a token from the network which uniquely identifies the transaction.
    Visa calls this the Transaction ID, Mastercard calls this the Trace ID, and American Express calls this the Acquirer Reference Data.
    Note that you should pass in a Network Transaction ID if you have one, regardless of whether this is a
    Customer-Initiated Transaction (CIT) or a Merchant-Initiated Transaction (MIT).
    """


class OffSessionPaymentCreateParamsPaymentsOrchestration(TypedDict):
    enabled: bool
    """
    True when you want to enable payments orchestration for this off-session payment. False otherwise.
    """


class OffSessionPaymentCreateParamsRetryDetails(TypedDict):
    retry_policy: NotRequired[str]
    """
    The pre-configured retry policy to use for the payment.
    """
    retry_strategy: NotRequired[Literal["best_available", "none"]]
    """
    Indicates the strategy for how you want Stripe to retry the payment.
    """


class OffSessionPaymentCreateParamsTransferData(TypedDict):
    amount: NotRequired[int]
    """
    The amount transferred to the destination account. This transfer will occur
    automatically after the payment succeeds. If no amount is specified, by default
    the entire payment amount is transferred to the destination account. The amount
    must be less than or equal to the
    [amount_requested](https://docs.stripe.com/api/v2/off-session-payments/object?api-version=2025-05-28.preview#v2_off_session_payment_object-amount_requested),
    and must be a positive integer representing how much to transfer in the smallest
    currency unit (e.g., 100 cents to charge $1.00).
    """
    destination: str
    """
    The account (if any) that the payment is attributed to for tax reporting, and
    where funds from the payment are transferred to after payment success.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._api_mode import ApiMode
from stripe._stripe_object import StripeObject
from stripe._stripe_response import StripeResponse
from stripe.v2.core._event import Event, EventNotification
from typing import Any, Dict, List, Optional, cast
from typing_extensions import Literal, TYPE_CHECKING, override

if TYPE_CHECKING:
    from stripe._api_requestor import _APIRequestor


class V2CoreAccountLinkReturnedEventNotification(EventNotification):
    LOOKUP_TYPE = "v2.core.account_link.returned"
    type: Literal["v2.core.account_link.returned"]

    @override
    def fetch_event(self) -> "V2CoreAccountLinkReturnedEvent":
        return cast(
            "V2CoreAccountLinkReturnedEvent",
            super().fetch_event(),
        )

    @override
    async def fetch_event_async(self) -> "V2CoreAccountLinkReturnedEvent":
        return cast(
            "V2CoreAccountLinkReturnedEvent",
            await super().fetch_event_async(),
        )


class V2CoreAccountLinkReturnedEvent(Event):
    LOOKUP_TYPE = "v2.core.account_link.returned"
    type: Literal["v2.core.account_link.returned"]

    class V2CoreAccountLinkReturnedEventData(StripeObject):
        account_id: str
        """
        The ID of the v2 account.
        """
        configurations: List[
            Literal["customer", "merchant", "recipient", "storer"]
        ]
        """
        Configurations on the Account that was onboarded via the account link.
        """
        use_case: Literal["account_onboarding", "account_update"]
        """
        Open Enum. The use case type of the account link that has been completed.
        """

    data: V2CoreAccountLinkReturnedEventData
    """
    Data for the v2.core.account_link.returned event
    """

    @classmethod
    def _construct_from(
        cls,
        *,
        values: Dict[str, Any],
        last_response: Optional[StripeResponse] = None,
        requestor: "_APIRequestor",
        api_mode: ApiMode,
    ) -> "V2CoreAccountLinkReturnedEvent":
        evt = super()._construct_from(
            values=values,
            last_response=last_response,
            requestor=requestor,
            api_mode=api_mode,
        )
        if hasattr(evt, "data"):
            evt.data = V2CoreAccountLinkReturnedEvent.V2CoreAccountLinkReturnedEventData._construct_from(
                values=evt.data,
                last_response=last_response,
                requestor=requestor,
                api_mode=api_mode,
            )
        return evt



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import List
from typing_extensions import Literal, NotRequired, TypedDict


class SubscriptionPauseParams(RequestOptions):
    bill_for: NotRequired["SubscriptionPauseParamsBillFor"]
    """
    Controls what to bill for when pausing the subscription.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    invoicing_behavior: NotRequired[Literal["invoice", "pending_invoice_item"]]
    """
    Determines how to handle debits and credits when pausing. The default is `pending_invoice_item`.
    """
    type: Literal["subscription"]
    """
    The type of pause to apply.
    """


class SubscriptionPauseParamsBillFor(TypedDict):
    outstanding_usage: NotRequired[bool]
    """
    Controls whether to debit for accrued metered usage in the current billing period. The default is `false`.
    """
    unused_time: NotRequired[bool]
    """
    Controls whether to credit for licensed items in the current billing period. The default is `false`.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import List
from typing_extensions import Literal, NotRequired, TypedDict


class FinancialAccountListParams(TypedDict):
    limit: NotRequired[int]
    """
    The page limit.
    """
    status: NotRequired[Literal["closed", "open", "pending"]]
    """
    The status of the FinancialAccount to filter by. By default, closed FinancialAccounts are not returned.
    """
    types: NotRequired[List[Literal["payments", "storage"]]]
    """
    Filter for FinancialAccount `type`. By default, FinancialAccounts of any `type` are returned.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import Dict, List
from typing_extensions import Literal, NotRequired


class MeterListEventSummariesParams(RequestOptions):
    customer: str
    """
    The customer for which to fetch event summaries.
    """
    dimension_filters: NotRequired[Dict[str, str]]
    """
    Key-value pairs used to filter meter events by dimension values. If specified, event summaries will be generated with only matching meter events.
    """
    dimension_group_by_keys: NotRequired[List[str]]
    """
    List of dimension payload keys to group by. If specified, event summaries will be grouped by the given dimension payload key values.
    """
    end_time: int
    """
    The timestamp from when to stop aggregating meter events (exclusive). Must be aligned with minute boundaries.
    """
    ending_before: NotRequired[str]
    """
    A cursor for use in pagination. `ending_before` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, starting with `obj_bar`, your subsequent call can include `ending_before=obj_bar` in order to fetch the previous page of the list.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    limit: NotRequired[int]
    """
    A limit on the number of objects to be returned. Limit can range between 1 and 100, and the default is 10.
    """
    start_time: int
    """
    The timestamp from when to start aggregating meter events (inclusive). Must be aligned with minute boundaries.
    """
    starting_after: NotRequired[str]
    """
    A cursor for use in pagination. `starting_after` is an object ID that defines your place in the list. For instance, if you make a list request and receive 100 objects, ending with `obj_foo`, your subsequent call can include `starting_after=obj_foo` in order to fetch the next page of the list.
    """
    value_grouping_window: NotRequired[Literal["day", "hour"]]
    """
    Specifies what granularity to use when generating event summaries. If not specified, a single event summary would be returned for the specified time range. For hourly granularity, start and end times must align with hour boundaries (e.g., 00:00, 01:00, ..., 23:00). For daily granularity, start and end times must align with UTC day boundaries (00:00 UTC).
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from importlib import import_module
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe.params.checkout._session_create_params import (
        SessionCreateParams as SessionCreateParams,
        SessionCreateParamsAdaptivePricing as SessionCreateParamsAdaptivePricing,
        SessionCreateParamsAfterExpiration as SessionCreateParamsAfterExpiration,
        SessionCreateParamsAfterExpirationRecovery as SessionCreateParamsAfterExpirationRecovery,
        SessionCreateParamsAutomaticTax as SessionCreateParamsAutomaticTax,
        SessionCreateParamsAutomaticTaxLiability as SessionCreateParamsAutomaticTaxLiability,
        SessionCreateParamsBrandingSettings as SessionCreateParamsBrandingSettings,
        SessionCreateParamsBrandingSettingsIcon as SessionCreateParamsBrandingSettingsIcon,
        SessionCreateParamsBrandingSettingsLogo as SessionCreateParamsBrandingSettingsLogo,
        SessionCreateParamsCheckoutItem as SessionCreateParamsCheckoutItem,
        SessionCreateParamsCheckoutItemPricingPlanSubscriptionItem as SessionCreateParamsCheckoutItemPricingPlanSubscriptionItem,
        SessionCreateParamsCheckoutItemPricingPlanSubscriptionItemComponentConfigurations as SessionCreateParamsCheckoutItemPricingPlanSubscriptionItemComponentConfigurations,
        SessionCreateParamsCheckoutItemPricingPlanSubscriptionItemComponentConfigurationsLicenseFeeComponent as SessionCreateParamsCheckoutItemPricingPlanSubscriptionItemComponentConfigurationsLicenseFeeComponent,
        SessionCreateParamsCheckoutItemRateCardSubscriptionItem as SessionCreateParamsCheckoutItemRateCardSubscriptionItem,
        SessionCreateParamsConsentCollection as SessionCreateParamsConsentCollection,
        SessionCreateParamsConsentCollectionPaymentMethodReuseAgreement as SessionCreateParamsConsentCollectionPaymentMethodReuseAgreement,
        SessionCreateParamsCustomField as SessionCreateParamsCustomField,
        SessionCreateParamsCustomFieldDropdown as SessionCreateParamsCustomFieldDropdown,
        SessionCreateParamsCustomFieldDropdownOption as SessionCreateParamsCustomFieldDropdownOption,
        SessionCreateParamsCustomFieldLabel as SessionCreateParamsCustomFieldLabel,
        SessionCreateParamsCustomFieldNumeric as SessionCreateParamsCustomFieldNumeric,
        SessionCreateParamsCustomFieldText as SessionCreateParamsCustomFieldText,
        SessionCreateParamsCustomText as SessionCreateParamsCustomText,
        SessionCreateParamsCustomTextAfterSubmit as SessionCreateParamsCustomTextAfterSubmit,
        SessionCreateParamsCustomTextShippingAddress as SessionCreateParamsCustomTextShippingAddress,
        SessionCreateParamsCustomTextSubmit as SessionCreateParamsCustomTextSubmit,
        SessionCreateParamsCustomTextTermsOfServiceAcceptance as SessionCreateParamsCustomTextTermsOfServiceAcceptance,
        SessionCreateParamsCustomerUpdate as SessionCreateParamsCustomerUpdate,
        SessionCreateParamsDiscount as SessionCreateParamsDiscount,
        SessionCreateParamsDiscountCouponData as SessionCreateParamsDiscountCouponData,
        SessionCreateParamsInvoiceCreation as SessionCreateParamsInvoiceCreation,
        SessionCreateParamsInvoiceCreationInvoiceData as SessionCreateParamsInvoiceCreationInvoiceData,
        SessionCreateParamsInvoiceCreationInvoiceDataCustomField as SessionCreateParamsInvoiceCreationInvoiceDataCustomField,
        SessionCreateParamsInvoiceCreationInvoiceDataIssuer as SessionCreateParamsInvoiceCreationInvoiceDataIssuer,
        SessionCreateParamsInvoiceCreationInvoiceDataRenderingOptions as SessionCreateParamsInvoiceCreationInvoiceDataRenderingOptions,
        SessionCreateParamsLineItem as SessionCreateParamsLineItem,
        SessionCreateParamsLineItemAdjustableQuantity as SessionCreateParamsLineItemAdjustableQuantity,
        SessionCreateParamsLineItemPriceData as SessionCreateParamsLineItemPriceData,
        SessionCreateParamsLineItemPriceDataProductData as SessionCreateParamsLineItemPriceDataProductData,
        SessionCreateParamsLineItemPriceDataProductDataTaxDetails as SessionCreateParamsLineItemPriceDataProductDataTaxDetails,
        SessionCreateParamsLineItemPriceDataRecurring as SessionCreateParamsLineItemPriceDataRecurring,
        SessionCreateParamsNameCollection as SessionCreateParamsNameCollection,
        SessionCreateParamsNameCollectionBusiness as SessionCreateParamsNameCollectionBusiness,
        SessionCreateParamsNameCollectionIndividual as SessionCreateParamsNameCollectionIndividual,
        SessionCreateParamsOptionalItem as SessionCreateParamsOptionalItem,
        SessionCreateParamsOptionalItemAdjustableQuantity as SessionCreateParamsOptionalItemAdjustableQuantity,
        SessionCreateParamsPaymentIntentData as SessionCreateParamsPaymentIntentData,
        SessionCreateParamsPaymentIntentDataShipping as SessionCreateParamsPaymentIntentDataShipping,
        SessionCreateParamsPaymentIntentDataShippingAddress as SessionCreateParamsPaymentIntentDataShippingAddress,
        SessionCreateParamsPaymentIntentDataTransferData as SessionCreateParamsPaymentIntentDataTransferData,
        SessionCreateParamsPaymentMethodData as SessionCreateParamsPaymentMethodData,
        SessionCreateParamsPaymentMethodOptions as SessionCreateParamsPaymentMethodOptions,
        SessionCreateParamsPaymentMethodOptionsAcssDebit as SessionCreateParamsPaymentMethodOptionsAcssDebit,
        SessionCreateParamsPaymentMethodOptionsAcssDebitMandateOptions as SessionCreateParamsPaymentMethodOptionsAcssDebitMandateOptions,
        SessionCreateParamsPaymentMethodOptionsAffirm as SessionCreateParamsPaymentMethodOptionsAffirm,
        SessionCreateParamsPaymentMethodOptionsAfterpayClearpay as SessionCreateParamsPaymentMethodOptionsAfterpayClearpay,
        SessionCreateParamsPaymentMethodOptionsAlipay as SessionCreateParamsPaymentMethodOptionsAlipay,
        SessionCreateParamsPaymentMethodOptionsAlma as SessionCreateParamsPaymentMethodOptionsAlma,
        SessionCreateParamsPaymentMethodOptionsAmazonPay as SessionCreateParamsPaymentMethodOptionsAmazonPay,
        SessionCreateParamsPaymentMethodOptionsAuBecsDebit as SessionCreateParamsPaymentMethodOptionsAuBecsDebit,
        SessionCreateParamsPaymentMethodOptionsBacsDebit as SessionCreateParamsPaymentMethodOptionsBacsDebit,
        SessionCreateParamsPaymentMethodOptionsBacsDebitMandateOptions as SessionCreateParamsPaymentMethodOptionsBacsDebitMandateOptions,
        SessionCreateParamsPaymentMethodOptionsBancontact as SessionCreateParamsPaymentMethodOptionsBancontact,
        SessionCreateParamsPaymentMethodOptionsBillie as SessionCreateParamsPaymentMethodOptionsBillie,
        SessionCreateParamsPaymentMethodOptionsBoleto as SessionCreateParamsPaymentMethodOptionsBoleto,
        SessionCreateParamsPaymentMethodOptionsCard as SessionCreateParamsPaymentMethodOptionsCard,
        SessionCreateParamsPaymentMethodOptionsCardInstallments as SessionCreateParamsPaymentMethodOptionsCardInstallments,
        SessionCreateParamsPaymentMethodOptionsCardRestrictions as SessionCreateParamsPaymentMethodOptionsCardRestrictions,
        SessionCreateParamsPaymentMethodOptionsCashapp as SessionCreateParamsPaymentMethodOptionsCashapp,
        SessionCreateParamsPaymentMethodOptionsCustomerBalance as SessionCreateParamsPaymentMethodOptionsCustomerBalance,
        SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer as SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer,
        SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer as SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer,
        SessionCreateParamsPaymentMethodOptionsDemoPay as SessionCreateParamsPaymentMethodOptionsDemoPay,
        SessionCreateParamsPaymentMethodOptionsEps as SessionCreateParamsPaymentMethodOptionsEps,
        SessionCreateParamsPaymentMethodOptionsFpx as SessionCreateParamsPaymentMethodOptionsFpx,
        SessionCreateParamsPaymentMethodOptionsGiropay as SessionCreateParamsPaymentMethodOptionsGiropay,
        SessionCreateParamsPaymentMethodOptionsGrabpay as SessionCreateParamsPaymentMethodOptionsGrabpay,
        SessionCreateParamsPaymentMethodOptionsIdeal as SessionCreateParamsPaymentMethodOptionsIdeal,
        SessionCreateParamsPaymentMethodOptionsKakaoPay as SessionCreateParamsPaymentMethodOptionsKakaoPay,
        SessionCreateParamsPaymentMethodOptionsKlarna as SessionCreateParamsPaymentMethodOptionsKlarna,
        SessionCreateParamsPaymentMethodOptionsKlarnaSubscription as SessionCreateParamsPaymentMethodOptionsKlarnaSubscription,
        SessionCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling as SessionCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling,
        SessionCreateParamsPaymentMethodOptionsKonbini as SessionCreateParamsPaymentMethodOptionsKonbini,
        SessionCreateParamsPaymentMethodOptionsKrCard as SessionCreateParamsPaymentMethodOptionsKrCard,
        SessionCreateParamsPaymentMethodOptionsLink as SessionCreateParamsPaymentMethodOptionsLink,
        SessionCreateParamsPaymentMethodOptionsMobilepay as SessionCreateParamsPaymentMethodOptionsMobilepay,
        SessionCreateParamsPaymentMethodOptionsMultibanco as SessionCreateParamsPaymentMethodOptionsMultibanco,
        SessionCreateParamsPaymentMethodOptionsNaverPay as SessionCreateParamsPaymentMethodOptionsNaverPay,
        SessionCreateParamsPaymentMethodOptionsOxxo as SessionCreateParamsPaymentMethodOptionsOxxo,
        SessionCreateParamsPaymentMethodOptionsP24 as SessionCreateParamsPaymentMethodOptionsP24,
        SessionCreateParamsPaymentMethodOptionsPayByBank as SessionCreateParamsPaymentMethodOptionsPayByBank,
        SessionCreateParamsPaymentMethodOptionsPayco as SessionCreateParamsPaymentMethodOptionsPayco,
        SessionCreateParamsPaymentMethodOptionsPaynow as SessionCreateParamsPaymentMethodOptionsPaynow,
        SessionCreateParamsPaymentMethodOptionsPaypal as SessionCreateParamsPaymentMethodOptionsPaypal,
        SessionCreateParamsPaymentMethodOptionsPayto as SessionCreateParamsPaymentMethodOptionsPayto,
        SessionCreateParamsPaymentMethodOptionsPaytoMandateOptions as SessionCreateParamsPaymentMethodOptionsPaytoMandateOptions,
        SessionCreateParamsPaymentMethodOptionsPix as SessionCreateParamsPaymentMethodOptionsPix,
        SessionCreateParamsPaymentMethodOptionsPixMandateOptions as SessionCreateParamsPaymentMethodOptionsPixMandateOptions,
        SessionCreateParamsPaymentMethodOptionsRevolutPay as SessionCreateParamsPaymentMethodOptionsRevolutPay,
        SessionCreateParamsPaymentMethodOptionsSamsungPay as SessionCreateParamsPaymentMethodOptionsSamsungPay,
        SessionCreateParamsPaymentMethodOptionsSatispay as SessionCreateParamsPaymentMethodOptionsSatispay,
        SessionCreateParamsPaymentMethodOptionsSepaDebit as SessionCreateParamsPaymentMethodOptionsSepaDebit,
        SessionCreateParamsPaymentMethodOptionsSepaDebitMandateOptions as SessionCreateParamsPaymentMethodOptionsSepaDebitMandateOptions,
        SessionCreateParamsPaymentMethodOptionsSofort as SessionCreateParamsPaymentMethodOptionsSofort,
        SessionCreateParamsPaymentMethodOptionsSwish as SessionCreateParamsPaymentMethodOptionsSwish,
        SessionCreateParamsPaymentMethodOptionsTwint as SessionCreateParamsPaymentMethodOptionsTwint,
        SessionCreateParamsPaymentMethodOptionsUsBankAccount as SessionCreateParamsPaymentMethodOptionsUsBankAccount,
        SessionCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections as SessionCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections,
        SessionCreateParamsPaymentMethodOptionsWechatPay as SessionCreateParamsPaymentMethodOptionsWechatPay,
        SessionCreateParamsPermissions as SessionCreateParamsPermissions,
        SessionCreateParamsPermissionsUpdate as SessionCreateParamsPermissionsUpdate,
        SessionCreateParamsPhoneNumberCollection as SessionCreateParamsPhoneNumberCollection,
        SessionCreateParamsSavedPaymentMethodOptions as SessionCreateParamsSavedPaymentMethodOptions,
        SessionCreateParamsSetupIntentData as SessionCreateParamsSetupIntentData,
        SessionCreateParamsShippingAddressCollection as SessionCreateParamsShippingAddressCollection,
        SessionCreateParamsShippingOption as SessionCreateParamsShippingOption,
        SessionCreateParamsShippingOptionShippingRateData as SessionCreateParamsShippingOptionShippingRateData,
        SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimate as SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimate,
        SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum as SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum,
        SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum as SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum,
        SessionCreateParamsShippingOptionShippingRateDataFixedAmount as SessionCreateParamsShippingOptionShippingRateDataFixedAmount,
        SessionCreateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions as SessionCreateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions,
        SessionCreateParamsSubscriptionData as SessionCreateParamsSubscriptionData,
        SessionCreateParamsSubscriptionDataBillingMode as SessionCreateParamsSubscriptionDataBillingMode,
        SessionCreateParamsSubscriptionDataBillingModeFlexible as SessionCreateParamsSubscriptionDataBillingModeFlexible,
        SessionCreateParamsSubscriptionDataInvoiceSettings as SessionCreateParamsSubscriptionDataInvoiceSettings,
        SessionCreateParamsSubscriptionDataInvoiceSettingsIssuer as SessionCreateParamsSubscriptionDataInvoiceSettingsIssuer,
        SessionCreateParamsSubscriptionDataTransferData as SessionCreateParamsSubscriptionDataTransferData,
        SessionCreateParamsSubscriptionDataTrialSettings as SessionCreateParamsSubscriptionDataTrialSettings,
        SessionCreateParamsSubscriptionDataTrialSettingsEndBehavior as SessionCreateParamsSubscriptionDataTrialSettingsEndBehavior,
        SessionCreateParamsTaxIdCollection as SessionCreateParamsTaxIdCollection,
        SessionCreateParamsWalletOptions as SessionCreateParamsWalletOptions,
        SessionCreateParamsWalletOptionsLink as SessionCreateParamsWalletOptionsLink,
    )
    from stripe.params.checkout._session_expire_params import (
        SessionExpireParams as SessionExpireParams,
    )
    from stripe.params.checkout._session_line_item_list_params import (
        SessionLineItemListParams as SessionLineItemListParams,
    )
    from stripe.params.checkout._session_list_line_items_params import (
        SessionListLineItemsParams as SessionListLineItemsParams,
    )
    from stripe.params.checkout._session_list_params import (
        SessionListParams as SessionListParams,
        SessionListParamsCreated as SessionListParamsCreated,
        SessionListParamsCustomerDetails as SessionListParamsCustomerDetails,
    )
    from stripe.params.checkout._session_modify_params import (
        SessionModifyParams as SessionModifyParams,
        SessionModifyParamsAutomaticTax as SessionModifyParamsAutomaticTax,
        SessionModifyParamsAutomaticTaxLiability as SessionModifyParamsAutomaticTaxLiability,
        SessionModifyParamsCollectedInformation as SessionModifyParamsCollectedInformation,
        SessionModifyParamsCollectedInformationShippingDetails as SessionModifyParamsCollectedInformationShippingDetails,
        SessionModifyParamsCollectedInformationShippingDetailsAddress as SessionModifyParamsCollectedInformationShippingDetailsAddress,
        SessionModifyParamsDiscount as SessionModifyParamsDiscount,
        SessionModifyParamsDiscountCouponData as SessionModifyParamsDiscountCouponData,
        SessionModifyParamsInvoiceCreation as SessionModifyParamsInvoiceCreation,
        SessionModifyParamsInvoiceCreationInvoiceData as SessionModifyParamsInvoiceCreationInvoiceData,
        SessionModifyParamsInvoiceCreationInvoiceDataIssuer as SessionModifyParamsInvoiceCreationInvoiceDataIssuer,
        SessionModifyParamsLineItem as SessionModifyParamsLineItem,
        SessionModifyParamsLineItemAdjustableQuantity as SessionModifyParamsLineItemAdjustableQuantity,
        SessionModifyParamsLineItemPriceData as SessionModifyParamsLineItemPriceData,
        SessionModifyParamsLineItemPriceDataProductData as SessionModifyParamsLineItemPriceDataProductData,
        SessionModifyParamsLineItemPriceDataProductDataTaxDetails as SessionModifyParamsLineItemPriceDataProductDataTaxDetails,
        SessionModifyParamsLineItemPriceDataRecurring as SessionModifyParamsLineItemPriceDataRecurring,
        SessionModifyParamsShippingOption as SessionModifyParamsShippingOption,
        SessionModifyParamsShippingOptionShippingRateData as SessionModifyParamsShippingOptionShippingRateData,
        SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimate as SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimate,
        SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMaximum as SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMaximum,
        SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMinimum as SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMinimum,
        SessionModifyParamsShippingOptionShippingRateDataFixedAmount as SessionModifyParamsShippingOptionShippingRateDataFixedAmount,
        SessionModifyParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions as SessionModifyParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions,
        SessionModifyParamsSubscriptionData as SessionModifyParamsSubscriptionData,
        SessionModifyParamsSubscriptionDataInvoiceSettings as SessionModifyParamsSubscriptionDataInvoiceSettings,
        SessionModifyParamsSubscriptionDataInvoiceSettingsIssuer as SessionModifyParamsSubscriptionDataInvoiceSettingsIssuer,
    )
    from stripe.params.checkout._session_retrieve_params import (
        SessionRetrieveParams as SessionRetrieveParams,
    )
    from stripe.params.checkout._session_update_params import (
        SessionUpdateParams as SessionUpdateParams,
        SessionUpdateParamsAutomaticTax as SessionUpdateParamsAutomaticTax,
        SessionUpdateParamsAutomaticTaxLiability as SessionUpdateParamsAutomaticTaxLiability,
        SessionUpdateParamsCollectedInformation as SessionUpdateParamsCollectedInformation,
        SessionUpdateParamsCollectedInformationShippingDetails as SessionUpdateParamsCollectedInformationShippingDetails,
        SessionUpdateParamsCollectedInformationShippingDetailsAddress as SessionUpdateParamsCollectedInformationShippingDetailsAddress,
        SessionUpdateParamsDiscount as SessionUpdateParamsDiscount,
        SessionUpdateParamsDiscountCouponData as SessionUpdateParamsDiscountCouponData,
        SessionUpdateParamsInvoiceCreation as SessionUpdateParamsInvoiceCreation,
        SessionUpdateParamsInvoiceCreationInvoiceData as SessionUpdateParamsInvoiceCreationInvoiceData,
        SessionUpdateParamsInvoiceCreationInvoiceDataIssuer as SessionUpdateParamsInvoiceCreationInvoiceDataIssuer,
        SessionUpdateParamsLineItem as SessionUpdateParamsLineItem,
        SessionUpdateParamsLineItemAdjustableQuantity as SessionUpdateParamsLineItemAdjustableQuantity,
        SessionUpdateParamsLineItemPriceData as SessionUpdateParamsLineItemPriceData,
        SessionUpdateParamsLineItemPriceDataProductData as SessionUpdateParamsLineItemPriceDataProductData,
        SessionUpdateParamsLineItemPriceDataProductDataTaxDetails as SessionUpdateParamsLineItemPriceDataProductDataTaxDetails,
        SessionUpdateParamsLineItemPriceDataRecurring as SessionUpdateParamsLineItemPriceDataRecurring,
        SessionUpdateParamsShippingOption as SessionUpdateParamsShippingOption,
        SessionUpdateParamsShippingOptionShippingRateData as SessionUpdateParamsShippingOptionShippingRateData,
        SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimate as SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimate,
        SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum as SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum,
        SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum as SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum,
        SessionUpdateParamsShippingOptionShippingRateDataFixedAmount as SessionUpdateParamsShippingOptionShippingRateDataFixedAmount,
        SessionUpdateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions as SessionUpdateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions,
        SessionUpdateParamsSubscriptionData as SessionUpdateParamsSubscriptionData,
        SessionUpdateParamsSubscriptionDataInvoiceSettings as SessionUpdateParamsSubscriptionDataInvoiceSettings,
        SessionUpdateParamsSubscriptionDataInvoiceSettingsIssuer as SessionUpdateParamsSubscriptionDataInvoiceSettingsIssuer,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "SessionCreateParams": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsAdaptivePricing": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsAfterExpiration": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsAfterExpirationRecovery": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsAutomaticTax": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsAutomaticTaxLiability": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsBrandingSettings": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsBrandingSettingsIcon": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsBrandingSettingsLogo": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCheckoutItem": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCheckoutItemPricingPlanSubscriptionItem": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCheckoutItemPricingPlanSubscriptionItemComponentConfigurations": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCheckoutItemPricingPlanSubscriptionItemComponentConfigurationsLicenseFeeComponent": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCheckoutItemRateCardSubscriptionItem": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsConsentCollection": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsConsentCollectionPaymentMethodReuseAgreement": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomField": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomFieldDropdown": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomFieldDropdownOption": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomFieldLabel": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomFieldNumeric": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomFieldText": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomText": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomTextAfterSubmit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomTextShippingAddress": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomTextSubmit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomTextTermsOfServiceAcceptance": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsCustomerUpdate": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsDiscount": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsDiscountCouponData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsInvoiceCreation": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsInvoiceCreationInvoiceData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsInvoiceCreationInvoiceDataCustomField": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsInvoiceCreationInvoiceDataIssuer": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsInvoiceCreationInvoiceDataRenderingOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItem": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItemAdjustableQuantity": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItemPriceData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItemPriceDataProductData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItemPriceDataProductDataTaxDetails": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsLineItemPriceDataRecurring": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsNameCollection": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsNameCollectionBusiness": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsNameCollectionIndividual": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsOptionalItem": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsOptionalItemAdjustableQuantity": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentIntentData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentIntentDataShipping": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentIntentDataShippingAddress": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentIntentDataTransferData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAcssDebit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAcssDebitMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAffirm": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAfterpayClearpay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAlipay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAlma": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAmazonPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsAuBecsDebit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsBacsDebit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsBacsDebitMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsBancontact": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsBillie": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsBoleto": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCard": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCardInstallments": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCardRestrictions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCashapp": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCustomerBalance": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransfer": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsCustomerBalanceBankTransferEuBankTransfer": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsDemoPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsEps": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsFpx": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsGiropay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsGrabpay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsIdeal": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKakaoPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKlarna": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKlarnaSubscription": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKlarnaSubscriptionNextBilling": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKonbini": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsKrCard": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsLink": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsMobilepay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsMultibanco": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsNaverPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsOxxo": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsP24": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPayByBank": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPayco": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPaynow": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPaypal": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPayto": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPaytoMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPix": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsPixMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsRevolutPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSamsungPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSatispay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSepaDebit": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSepaDebitMandateOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSofort": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsSwish": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsTwint": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsUsBankAccount": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsUsBankAccountFinancialConnections": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPaymentMethodOptionsWechatPay": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPermissions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPermissionsUpdate": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsPhoneNumberCollection": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSavedPaymentMethodOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSetupIntentData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingAddressCollection": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOption": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimate": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateDataFixedAmount": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataBillingMode": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataBillingModeFlexible": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataInvoiceSettings": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataInvoiceSettingsIssuer": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataTransferData": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataTrialSettings": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsSubscriptionDataTrialSettingsEndBehavior": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsTaxIdCollection": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsWalletOptions": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionCreateParamsWalletOptionsLink": (
        "stripe.params.checkout._session_create_params",
        False,
    ),
    "SessionExpireParams": (
        "stripe.params.checkout._session_expire_params",
        False,
    ),
    "SessionLineItemListParams": (
        "stripe.params.checkout._session_line_item_list_params",
        False,
    ),
    "SessionListLineItemsParams": (
        "stripe.params.checkout._session_list_line_items_params",
        False,
    ),
    "SessionListParams": (
        "stripe.params.checkout._session_list_params",
        False,
    ),
    "SessionListParamsCreated": (
        "stripe.params.checkout._session_list_params",
        False,
    ),
    "SessionListParamsCustomerDetails": (
        "stripe.params.checkout._session_list_params",
        False,
    ),
    "SessionModifyParams": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsAutomaticTax": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsAutomaticTaxLiability": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsCollectedInformation": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsCollectedInformationShippingDetails": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsCollectedInformationShippingDetailsAddress": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsDiscount": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsDiscountCouponData": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsInvoiceCreation": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsInvoiceCreationInvoiceData": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsInvoiceCreationInvoiceDataIssuer": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItem": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItemAdjustableQuantity": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItemPriceData": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItemPriceDataProductData": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItemPriceDataProductDataTaxDetails": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsLineItemPriceDataRecurring": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOption": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateData": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimate": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateDataFixedAmount": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsSubscriptionData": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsSubscriptionDataInvoiceSettings": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionModifyParamsSubscriptionDataInvoiceSettingsIssuer": (
        "stripe.params.checkout._session_modify_params",
        False,
    ),
    "SessionRetrieveParams": (
        "stripe.params.checkout._session_retrieve_params",
        False,
    ),
    "SessionUpdateParams": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsAutomaticTax": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsAutomaticTaxLiability": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsCollectedInformation": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsCollectedInformationShippingDetails": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsCollectedInformationShippingDetailsAddress": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsDiscount": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsDiscountCouponData": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsInvoiceCreation": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsInvoiceCreationInvoiceData": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsInvoiceCreationInvoiceDataIssuer": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItem": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItemAdjustableQuantity": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItemPriceData": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItemPriceDataProductData": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItemPriceDataProductDataTaxDetails": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsLineItemPriceDataRecurring": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOption": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateData": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimate": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMaximum": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateDataDeliveryEstimateMinimum": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateDataFixedAmount": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsShippingOptionShippingRateDataFixedAmountCurrencyOptions": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsSubscriptionData": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsSubscriptionDataInvoiceSettings": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
    "SessionUpdateParamsSubscriptionDataInvoiceSettingsIssuer": (
        "stripe.params.checkout._session_update_params",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import List
from typing_extensions import Literal, NotRequired


class SetupIntentCancelParams(RequestOptions):
    cancellation_reason: NotRequired[
        Literal["abandoned", "duplicate", "requested_by_customer"]
    ]
    """
    Reason for canceling this SetupIntent. Possible values are: `abandoned`, `requested_by_customer`, or `duplicate`
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
